@@ -2,6 +2,7 @@ library(insurancerating)
 context("fitgam")
 
 test_that("check if object is of fitgam class", {
-  x <- fit_gam(MTPL, nclaims = nclaims, x = age_policyholder, exposure = exposure)
+  x <- fit_gam(MTPL, nclaims = nclaims, x = age_policyholder,
+               exposure = exposure)
   expect_is(x, "fitgam")
 })
