@@ -38,18 +38,6 @@ test_that("check if average premium is calculated", {
   expect_true("average_premium" %in% names(x))
 })
 
-test_that("check correct error message if column that does not exist is used", {
-  expect_error(univariate(MTPL2, x = areaaa, premium = premium,
-                          exposure = exposure),
-               "Column areaaa can't be found")
-})
-
-test_that("check if correct attribute for `by` is returned if length = 1", {
-  x <- univariate(MTPL, x = zip, nclaims = nclaims, exposure = exposure,
-                  by = bm)
-  expect_equal(as.character(attr(x, "by")[[1]]), "bm")
-})
-
 test_that("check if correct attribute for `by` is returned if length > 1", {
   x <- univariate(MTPL, x = zip, nclaims = nclaims, exposure = exposure,
                   by = list(bm, power))
@@ -58,6 +46,6 @@ test_that("check if correct attribute for `by` is returned if length > 1", {
 
 test_that("check if correct attribute for `by` is returned if length = 0", {
   x <- univariate(MTPL, x = zip, nclaims = nclaims, exposure = exposure)
-  expect_equal(length(attr(x, "by")), 0)
+  expect_equal(attr(x, "by"), "NULL")
 })
 
